@@ -64,9 +64,10 @@ class gNMIclient(object):
         else:
             self.__target = target
 
-        if 'interval_ms' in kwargs:
+        if 'keepalive_time_ms' in kwargs:
             self.configureKeepalive(**kwargs)
 
+
     def configureKeepalive(self, keepalive_time_ms: int, keepalive_timeout_ms: int = 20000,
                            max_pings_without_data: int = 0,
                            keepalive_permit_without_calls: bool = True):
@@ -85,6 +86,7 @@ class gNMIclient(object):
           ("grpc.http2.max_pings_without_data", max_pings_without_data),
         ]
 
+
     def __enter__(self):
         """
         Building the connectivity towards network element over gNMI (used in the with ... as ... context manager)
